@@ -41,12 +41,15 @@ Configuration file for Home Site Maker
 */
 
 
-$VERSION="homesitemaker-v0.4.5";                     // [STOP] Only for upgrading purporses
+$VERSION="homesitemaker-v0.4.6";                     // [STOP] Only for upgrading purporses
 $TITLE="Homesite Maker";                             // [EDIT] The title of your website
 $DESCRIPTION="The Homesite Maker project home page"; // [EDIT] A brief description of your website
 $URL="http://homesitemaker-devel-local.org";         // [REQUIRED] The URL used to serve your site
 
 $SKIN="white_clouds"; // [OPT] Available skins are rainbow, aqua, simple, black-simple, black-grey and white_clouds
+$ICONS="white_clouds";// [OPT] Available icon-set is white_clouds
+$ICON_SIZE1="32";     // [OPT] Available values are 64, 48, 32 and 22
+$ICON_SIZE2="48";     // [OPT] Available values are 64, 48, 32 and 22
 $HEADER_WIDTH="90%";  // [OPT] Use porcentual value (%) or in pixels
 $BODY_WIDTH="90%";    // [OPT] Use porcentual value (%) or in pixels
 $LANGUAGE="english";  // [EDIT] Available languages are english, spanish and catalan.
@@ -109,8 +112,8 @@ $TAB_43="NO";             $SECTION_TYPE_43="NO";      // [EDIT][EDIT] Title and
 $TAB_44="NO";             $SECTION_TYPE_44="NO";      // [EDIT][EDIT] Title and type of the section 4 of the tab 4
 
 $TAB_51="Users";          $SECTION_TYPE_51="users";   // [TRANS][STOP] Don't touch this if you don't know what you are doing
-$TAB_52="Config";         $SECTION_TYPE_52="config";  // [TRANS][STOP] Don't touch this if you don't know what you are doing
-$TAB_53="Look & Feel";    $SECTION_TYPE_53="site";    // [TRANS][STOP] Don't touch this if you don't know what you are doing
+$TAB_52="Configuration";  $SECTION_TYPE_52="config";  // [TRANS][STOP] Don't touch this if you don't know what you are doing
+$TAB_53="Style";          $SECTION_TYPE_53="style";    // [TRANS][STOP] Don't touch this if you don't know what you are doing
 $TAB_54="Help";           $SECTION_TYPE_54="help";    // [TRANS][STOP] Don't touch this if you don't know what you are doing
 
 $P_ITEMS="YES";           // [OPT] If you wants to show pending items to be published in the left pannel say yes here.
