@@ -105,7 +105,7 @@ if (isset($_POST['allow_to_see_list'])) {$allow_to_see_list=$_POST['allow_to_see
 if (isset($_POST['allow_to_add_list'])) {$allow_to_add_list=$_POST['allow_to_add_list'];} else {$allow_to_add_list="all";}
 if (isset($_POST['id_photo_list'])) {$id_photo_list=$_POST['id_photo_list'];} else {$id_photo_list="NULL";}
 if (isset($_POST['filename_list'])) {$filename_list=$_POST['filename_list'];} else {$filename_list="NULL";}
-
+if (isset($_POST['photo_comment_list'])) {$photo_comment_list=$_POST['photo_comment_list'];} else {$photo_comment_list="NULL";}
 
 
 function check_user_form ($new_nick, $password, $password_check, $n){
@@ -402,6 +402,33 @@ if ($id_photo_list=="all")
 return 0;
 }
 
+function dbwa_edit_photo_comments ($id_album,$id_photo_list,$photo_comment_list){
+global $LANGUAGE;
+include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");
+include ("config_site.php");
+include ("db_connect.php");
+$n=0;
+foreach ($id_photo_list as $value)
+                  {
+                  $photo_query=mysql_query("SELECT filename, description
+                                           FROM photo_album
+                                           WHERE id_photo='".$value."' AND id_album='".$id_album."'", $db);
+                  $photo_result=mysql_fetch_array($photo_query);
+
+                  mysql_query ("UPDATE photo_album 
+                                SET description='".$photo_comment_list[$n]."'
+                                WHERE id_photo='".$value."' AND id_album='".$id_album."'" ,$db);
+
+                  echo "<span class=\"text1\"><center>".
+                       "".$photo_result['filename']." <b>".$photo_result['description']."</b> $TEXT020".
+                       " <b>$photo_comment_list[$n]</b></center></span>";
+                  // Uncoment only for debbuging
+                  //echo "value-> $value, filename->$filename_list[$n]<br>";
+                  $n++;
+                  }
+return 0;
+}
+
 function dbwa_put_comment ($id_info, $id_author, $id_comment, $posted, $title, $body_text, $text_type){
 include ("config_site.php");
 include ("db_connect.php");
@@ -900,6 +927,7 @@ if(isset($dbwa) && $dbwa!="NULL")
     if ($dbwa=="dbwa_edit_album") $dbwa ($id_album, $title, $description, $posted, "TAB_$top_tab$section_type",$allow_to_see, $allow_to_add, $allow_to_see_list, $allow_to_add_list); 
     if ($dbwa=="dbwa_add_photo_album") $dbwa ($id_album,$id_session['id_user'], $description,$posted);
     if ($dbwa=="dbwa_delete_photo_album") $dbwa ($id_album,$id_photo_list,$filename_list);//delete all the photos and data album
+    if ($dbwa=="dbwa_edit_photo_comments") $dbwa ($id_album,$id_photo_list,$photo_comment_list);//edit all the photo comments
     echo "<div class=\"text1\" align=\"center\">$TEXT017. </div>";
     } else if ($dbwa=="dbwa_add_unprivileged_user" || $dbwa=="dbwa_put_comment" || $dbwa=="dbwa_add_info" || $dbwa=="dbwa_edit_info" || $dbwa=="dbwa_add_photo_album")
               {
