@@ -29,9 +29,8 @@ Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
 $TEXT001="Panel de Control";
 $TEXT002="Usuaris";
 $TEXT003="Configuraci&oacute;";
-$TEXT004="Apariencia";
-$TEXT005="Estad&iacute;stiques";
-$TEXT006="Cr&egrave;ditos";
+$TEXT004="Estil";
+$TEXT005="Cr&egrave;ditos";
 $TEXT007="No t'has validat com un usuari autoritzat !<br>".
          "El Panel de Control es nom&ecute;s per usuaris enregistrats<br>amb privilegis d'administrador.<br>".
          "Probablement no hauries d'estar aqu&iacute;.";
