@@ -31,8 +31,7 @@ $HR001="Editat per &uacute;ltima vegada: ";
 $HR002="per";
 
 // Info Botton
-$IB000="Editar (GUI)";
-$IB001="Editar (texte)";
+$IB001="Editar";
 $IB002="Esborrar";
 
 // Info Edition Messages (IEM)
