@@ -32,10 +32,9 @@ Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
 
 $TEXT001="Control Panel";
 $TEXT002="Users";
-$TEXT003="Config";
-$TEXT004="Look and Feel";
-$TEXT005="Statics";
-$TEXT006="Credits";
+$TEXT003="Configuration";
+$TEXT004="Style";
+$TEXT005="Credits";
 $TEXT007="You are not logged as a correct user !<br>".
          "The Control Panel is only for registered users.<br>".
          "Maybe you shouldn't stay here";
