@@ -31,15 +31,13 @@ Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
 //---------- ./homesite/info.php ----------
 
 // Headline Row (HR)
-$TEXT001="Submit"; // See homesite-includes-dbwa.pnp before translate this
+$TEXT001="Submit"; // See homesite-includes-dbwa.php before translate this
 $TEXT002="Posted on";
 $TEXT003="by";
 $TEXT004="Last time edited";
-
 $TEXT005="Empty section !<br>".
          "Maybe you want to add some information here.<br>".
          "Otherwise you should remove this section.";
-
 $TEXT006="Comments";
 $TEXT007="Send comment";
 $TEXT008="Edit";
@@ -50,21 +48,12 @@ $TEXT012="Total";
 $TEXT013="Edition Date";
 $TEXT014="Author";
 $TEXT015="HeadLine";
-$TEXT048="Intro Text";
 $TEXT016="Body Text";
-$TEXT049="If you want to write a long article, it'll looks better if you divide it in two parts.".
-         "Use the Intro Text box to write a brief introduction text, and the Body Text box for the rest of the article.".
-         "If you are writing a small text, then use only the Body Text box.";
 $TEXT017="If you send as HTML, then the tags will be executed";
-$TEXT045="Send as:";
-$TEXT046="Plain text";
-$TEXT047="HTML";
-
 $TEXT018="This is the list with the current photos for this info.<br>".
          "You can select one or more to be deleted.<br>".
          "Otherwise, if you wants to add a new image for this info, ".
          "then select it in the following Attach Photo box.";
-
 $TEXT019="Delete";
 $TEXT020="Filename";
 $TEXT021="Id. Photo";
@@ -75,45 +64,46 @@ $TEXT025="Preview"; // See homesite-includes-dbwa.pnp before translate this
 $TEXT026="Publish"; // See homesite-includes-dbwa.pnp before translate this
 $TEXT027="Submit Date";
 $TEXT028="HeadLine";
-
 $TEXT029="The following is the list of news that are pending of your approval. ".
          "If you can see the list, then you have the neccesary privileges to do it.<br>".
          "You can select one or more news to be  deleted. Otherwise, click on the hedline ".
          "of the new that you want to edit or show.";
-
 $TEXT030="Id.Info";
 $TEXT031="Date";
 $TEXT032="There aren't pending news to be published.";
 $TEXT033="Deleting Date";
-
 $TEXT034="The selected new and all his comments will be lost if you continue.<br><br>".
          "Are you completly sure ?";
-
 $TEXT035="Empty section !<br>".
          "Maybe you want to add some information here.<br>".
          "Otherwise you should remove this section.";
-
 $TEXT036="Comment this new";
-
 $TEXT037="The following comments are owned by whoever posted them. ".
          "We are not responsible for them in any way.";
-
 $TEXT038="Reply to this comment";
 $TEXT039="Reply with title";
 $TEXT040="You are commenting this new";
 $TEXT041="You are answering this comment";
 $TEXT042="Comment title";
 $TEXT043="Text comment";
-
 $TEXT044="<br>You haven't enought permissions to publish pending news!<br><br>".
          "If you want to become Editor send an email to the site admin.<br>&nbsp;";
-$TEXT054="<br>You haven't enought permissions to edit news sended by other users!<br><br>".
-         "If you want to become Editor send an email to the site admin.<br>&nbsp;";
-$TEXT055="<br>You haven't enought permissions to delete news !<br><br>".
-         "If you want to become Editor send an email to the site admin.<br>&nbsp;";
+$TEXT045="Send as:";
+$TEXT046="Plain text";
+$TEXT047="HTML";
+$TEXT048="Intro Text";
+$TEXT049="If you want to write a long article, it'll looks better if you divide it in two parts.".
+         "Use the Intro Text box to write a brief introduction text, and the Body Text box for the rest of the article.".
+         "If you are writing a small text, then use only the Body Text box.";
 $TEXT050="Read more";
 $TEXT051="words";
 $TEXT052="$TITLE RSS 2.0 Feeds ";
 $TEXT053="Subscribe to the $TITLE news feed ! The following news channels are currently available:";
-$TEXT054="All the feeds on this page has been checked using";
+$TEXT054="<br>You haven't enought permissions to edit news sended by other users!<br><br>".
+         "If you want to become Editor send an email to the site admin.<br>&nbsp;";
+$TEXT055="<br>You haven't enought permissions to delete news !<br><br>".
+         "If you want to become Editor send an email to the site admin.<br>&nbsp;";
+$TEXT056="All the feeds on this page has been checked using";
+$TEXT057="Write your comment here !";
+$TEXT058="Write your text here !"
 ?>
